@@ -9,13 +9,12 @@
 #' Rather than forming pairs, cardinality matching selects the largest subset
 #' of units that satisfies user-supplied balance constraints on mean
 #' differences. One of several available optimization programs can be used to
-#' solve the mixed integer program. The default is the GLPK library as
-#' implemented in the *Rglpk* package, but performance can be dramatically
-#' improved using the HiGHS and the *highs* package, which are free, or Gurobi and the *gurobi* package, for which there is a
+#' solve the mixed integer program. The default is the HiGHS library as
+#' implemented in the *highs* package, both of which are free, but performance can be
+#' improved using Gurobi and the *gurobi* package, for which there is a
 #' free academic license.
 #'
-#' This page details the allowable arguments with `method =
-#' "cardinality"`. See [matchit()] for an explanation of what each argument
+#' This page details the allowable arguments with `method = "cardinality"`. See [matchit()] for an explanation of what each argument
 #' means in a general context and how it can be specified.
 #'
 #' Below is how `matchit()` is used for cardinality matching:
@@ -31,7 +30,7 @@
 #'         verbose = FALSE,
 #'         tols = .05,
 #'         std.tols = TRUE,
-#'         solver = "glpk",
+#'         solver = "highs",
 #'         ...) }
 #'
 #' @param formula a two-sided [formula] object containing the treatment and
@@ -57,13 +56,13 @@
 #' process should be printed to the console.
 #' @param \dots additional arguments that control the matching specification:
 #' \describe{
-#' \item{`tols`}{ `numeric`; a vector of imbalance
+#' \item{`tols`}{`numeric`; a vector of imbalance
 #' tolerances for mean differences, one for each covariate in `formula`.
 #' If only one value is supplied, it is applied to all. See `std.tols`
 #' below. Default is `.05` for standardized mean differences of at most
 #' .05 for all covariates between the treatment groups in the matched sample.
 #' }
-#' \item{`std.tols`}{ `logical`; whether each entry in `tols`
+#' \item{`std.tols`}{`logical`; whether each entry in `tols`
 #' corresponds to a raw or standardized mean difference. If only one value is
 #' supplied, it is applied to all. Default is `TRUE` for standardized mean
 #' differences. The standardization factor is the pooled standard deviation
@@ -77,7 +76,7 @@
 #' *Rglpk* package), SYMPHONY (implemented in the *Rsymphony*
 #' package), and Gurobi (implemented in the *gurobi* package),
 #' respectively. The differences between them are in speed and solving ability.
-#' GLPK (the default) and HiGHS are the easiest to install, but Gurobi is recommended as
+#' HiGHS (the default) and GLPK are the easiest to install, but Gurobi is recommended as
 #' it consistently outperforms other solvers and can find solutions even when
 #' others can't, and in less time. Gurobi is proprietary but can be used with a
 #' free trial or academic license. SYMPHONY may not produce reproducible
@@ -180,8 +179,7 @@
 #' to know exactly the cause of the failure and what measures should be taken
 #' to rectify it.
 #'
-#' A warning that says `"The optimizer failed to find an optimal solution
-#' in the time alotted. The returned solution may not be optimal."` usually
+#' A warning that says `"The optimizer failed to find an optimal solution in the time alotted. The returned solution may not be optimal."` usually
 #' means that an optimal solution may be possible to find with more time, in
 #' which case `time` should be increased or a faster solver should be
 #' used. Even with this warning, a potentially usable solution will be
@@ -211,7 +209,7 @@
 #' @references In a manuscript, you should reference the solver used in the
 #' optimization. For example, a sentence might read:
 #'
-#' *Cardinality matching was performed using the MatchIt package (Ho, Imai, King, & Stuart, 2011) in R with the optimization performed by HiGHs (Huangfu & Hall, 2018).*
+#' *Cardinality matching was performed using the MatchIt package (Ho, Imai, King, & Stuart, 2011) in R with the optimization performed by HiGHS (Huangfu & Hall, 2018).*
 #'
 #' See `vignette("matching-methods")` for more literature on cardinality
 #' matching.
@@ -221,43 +219,55 @@
 #'
 #' #Choose your solver; "gurobi" is best, "highs" is free and
 #' #easy to install
-#' solver <- "highs"
+#' \donttest{solver <- "highs"
 #'
-#' # 1:1 cardinality matching
+# 1:1 cardinality matching
 #' m.out1 <- matchit(treat ~ age + educ + re74,
-#'                   data = lalonde, method = "cardinality",
-#'                   estimand = "ATT", ratio = 1,
-#'                   tols = .2, solver = solver)
+#'                   data = lalonde,
+#'                   method = "cardinality",
+#'                   estimand = "ATT",
+#'                   ratio = 1,
+#'                   tols = .2,
+#'                   solver = solver)
 #' m.out1
 #' summary(m.out1)
 #'
 #' # Profile matching for the ATT
 #' m.out2 <- matchit(treat ~ age + educ + re74,
-#'                   data = lalonde, method = "cardinality",
-#'                   estimand = "ATT", ratio = NA,
-#'                   tols = .2, solver = solver)
+#'                   data = lalonde,
+#'                   method = "cardinality",
+#'                   estimand = "ATT",
+#'                   ratio = NA,
+#'                   tols = .2,
+#'                   solver = solver)
 #' m.out2
 #' summary(m.out2, un = FALSE)
 #'
 #' # Profile matching for the ATE
 #' m.out3 <- matchit(treat ~ age + educ + re74,
-#'                   data = lalonde, method = "cardinality",
-#'                   estimand = "ATE", ratio = NA,
-#'                   tols = .2, solver = solver)
+#'                   data = lalonde,
+#'                   method = "cardinality",
+#'                   estimand = "ATE",
+#'                   ratio = NA,
+#'                   tols = .2,
+#'                   solver = solver)
 #' m.out3
-#' summary(m.out3, un = FALSE)
+#' summary(m.out3, un = FALSE)}
 #' @examplesIf (requireNamespace("highs", quietly = TRUE) && requireNamespace("optmatch", quietly = TRUE))
-#' # Pairing after 1:1 cardinality matching:
+#' \donttest{# Pairing after 1:1 cardinality matching:
 #' m.out1b <- matchit(treat ~ age + educ + re74,
-#'                    data = lalonde, method = "cardinality",
-#'                    estimand = "ATT", ratio = 1,
-#'                    tols = .15, solver = solver,
+#'                    data = lalonde,
+#'                    method = "cardinality",
+#'                    estimand = "ATT",
+#'                    ratio = 1,
+#'                    tols = .15,
+#'                    solver = solver,
 #'                    mahvars = ~ age + educ + re74)
 #'
 #' # Note that balance doesn't change but pair distances
 #' # are lower for the paired-upon variables
 #' summary(m.out1b, un = FALSE)
-#' summary(m.out1, un = FALSE)
+#' summary(m.out1, un = FALSE)}
 #'
 #' # In these examples, a high tol was used and
 #' # few covariate matched on in order to not take too long;
@@ -265,43 +275,43 @@
 #' # covariates included if possible.
 NULL
 
-matchit2cardinality <-  function(treat, data, discarded, formula,
-                                 ratio = 1, focal = NULL, s.weights = NULL,
-                                 replace = FALSE, mahvars = NULL, exact = NULL,
-                                 estimand = "ATT", verbose = FALSE,
-                                 tols = .05, std.tols = TRUE,
-                                 solver = "glpk", time = 1*60, ...){
+matchit2cardinality <- function(treat, data, discarded, formula,
+                                ratio = 1, focal = NULL, s.weights = NULL,
+                                replace = FALSE, mahvars = NULL, exact = NULL,
+                                estimand = "ATT", verbose = FALSE,
+                                tols = .05, std.tols = TRUE,
+                                solver = "highs", time = 2 * 60, ...) {
 
-  if (verbose) {
-    cat("Cardinality matching... \n")
-  }
+  .cat_verbose("Cardinality matching... \n", verbose = verbose)
 
   tvals <- unique(treat)
   nt <- length(tvals)
 
   estimand <- toupper(estimand)
   estimand <- match_arg(estimand, c("ATT", "ATC", "ATE"))
-  if (!is.null(focal)) {
-    if (!focal %in% tvals) .err("`focal` must be a value of the treatment")
+  if (is_null(focal)) {
+    focal <- switch(estimand,
+                    "ATC" = min(tvals),
+                    max(tvals))
   }
-  else if (estimand == "ATC") {
-    focal <- min(tvals)
-  }
-  else {
-    focal <- max(tvals)
+  else if (!any(tvals == focal)) {
+    .err("`focal` must be a value of the treatment")
   }
 
   lab <- names(treat)
 
-  weights <- setNames(rep(0, length(treat)), lab)
+  weights <- rep_with(0, treat)
 
-  X <- get.covs.matrix(formula, data = data)
+  X <- get_covs_matrix(formula, data = data)
 
-  if (!is.null(exact)) {
-    ex <- factor(exactify(model.frame(exact, data = data), nam = lab, sep = ", ", include_vars = TRUE))
+  if (is_not_null(exact)) {
+    ex <- exactify(model.frame(exact, data = data), nam = lab, sep = ", ", include_vars = TRUE)
 
-    cc <- do.call("intersect", lapply(tvals, function(t) as.integer(ex)[treat == t]))
-    if (length(cc) == 0) .err("no matches were found")
+    cc <- Reduce("intersect", lapply(tvals, function(t) unclass(ex)[treat == t]))
+
+    if (is_null(cc)) {
+      .err("no matches were found")
+    }
   }
   else {
     ex <- gl(1, length(treat))
@@ -309,20 +319,17 @@ matchit2cardinality <-  function(treat, data, discarded, formula,
   }
 
   #Process mahvars
-  if (!is.null(mahvars)) {
+  if (is_not_null(mahvars)) {
     if (!is.finite(ratio) || !chk::vld_whole_number(ratio)) {
       .err("`mahvars` can only be used with `method = \"cardinality\"` when `ratio` is a whole number")
     }
+
     rlang::check_installed("optmatch")
+
     mahcovs <- transform_covariates(mahvars, data = data, method = "mahalanobis",
                                     s.weights = s.weights, treat = treat,
                                     discarded = discarded)
-    pair <- setNames(rep(NA_character_, length(treat)), lab)
-
-    #Set max problem size to Inf and return to original value after match
-    omps <- getOption("optmatch_max_problem_size")
-    on.exit(options(optmatch_max_problem_size = omps))
-    options(optmatch_max_problem_size = Inf)
+    pair <- rep_with(NA_character_, treat)
   }
   else {
     pair <- NULL
@@ -332,8 +339,8 @@ matchit2cardinality <-  function(treat, data, discarded, formula,
   assign <- get_assign(X)
 
   chk::chk_numeric(tols)
-  if (length(tols) == 1) {
-    tols <- rep(tols, ncol(X))
+  if (length(tols) == 1L) {
+    tols <- rep.int(tols, ncol(X))
   }
   else if (length(tols) == max(assign)) {
     tols <- tols[assign]
@@ -343,8 +350,8 @@ matchit2cardinality <-  function(treat, data, discarded, formula,
   }
 
   chk::chk_logical(std.tols)
-  if (length(std.tols) == 1) {
-    std.tols <- rep(std.tols, ncol(X))
+  if (length(std.tols) == 1L) {
+    std.tols <- rep.int(std.tols, ncol(X))
   }
   else if (length(std.tols) == max(assign)) {
     std.tols <- std.tols[assign]
@@ -355,6 +362,8 @@ matchit2cardinality <-  function(treat, data, discarded, formula,
 
   #Apply std.tols
   if (any(std.tols)) {
+    std.tols <- which(std.tols)
+
     sds <- {
       if (estimand == "ATE") {
         pooled_sd(X[, std.tols, drop = FALSE], t = treat,
@@ -366,48 +375,49 @@ matchit2cardinality <-  function(treat, data, discarded, formula,
       }
     }
 
-    zero.sds <- sds < 1e-10
-
-    X[,std.tols][,!zero.sds] <- scale(X[, std.tols, drop = FALSE][,!zero.sds, drop = FALSE],
-                                      center = FALSE, scale = sds[!zero.sds])
+    for (i in which(sds >= 1e-10)) {
+      X[, std.tols[i]] <- X[, std.tols[i]] / sds[i]
+    }
   }
 
   opt.out <- setNames(vector("list", nlevels(ex)), levels(ex))
 
   for (e in levels(ex)[cc]) {
-    if (nlevels(ex) > 1 && verbose) {
-      cat(sprintf("Matching subgroup %s/%s: %s...\n",
-                  match(e, levels(ex)[cc]), length(cc), e))
+    if (nlevels(ex) > 1L) {
+      .cat_verbose(sprintf("Matching subgroup %s/%s: %s...\n",
+                           match(e, levels(ex)[cc]), length(cc), e),
+                   verbose = verbose)
     }
 
-    in.exact <- which(!discarded & ex == e)
+    .e <- which(!discarded & ex == e)
 
-    treat_in.exact <- treat[in.exact]
+    treat_in.exact <- treat[.e]
     out <- cardinality_matchit(treat = treat_in.exact,
-                               X = X[in.exact,, drop = FALSE],
+                               X = X[.e, , drop = FALSE],
                                estimand = estimand, tols = tols,
-                               s.weights = s.weights[in.exact],
+                               s.weights = s.weights[.e],
                                ratio = ratio,
                                focal = focal, tvals = tvals,
                                solver = solver, time = time,
                                verbose = verbose)
 
-    weights[in.exact] <- out[["weights"]]
+    weights[.e] <- out[["weights"]]
     opt.out[[e]] <- out[["opt.out"]]
 
-    if (!is.null(mahvars)) {
-      mo <- eucdist_internal(mahcovs[in.exact[out[["weights"]] > 0],, drop = FALSE],
+    if (is_not_null(mahvars)) {
+      mo <- eucdist_internal(mahcovs[.e[out[["weights"]] > 0], , drop = FALSE],
                              treat_in.exact[out[["weights"]] > 0])
 
-      pm <- optmatch::pairmatch(mo,
-                                controls = ratio,
-                                data = data.frame(treat_in.exact))
-
+      rlang::with_options({
+        pm <- optmatch::pairmatch(mo,
+                                  controls = ratio,
+                                  data = data.frame(treat_in.exact))
+      }, optmatch_max_problem_size = Inf)
       pair[names(pm)[!is.na(pm)]] <- paste(as.character(pm[!is.na(pm)]), e, sep = "|")
     }
   }
 
-  if (!is.null(pair)) {
+  if (is_not_null(pair)) {
     psclass <- factor(pair)
     levels(psclass) <- seq_len(nlevels(psclass))
     names(psclass) <- names(treat)
@@ -419,14 +429,16 @@ matchit2cardinality <-  function(treat, data, discarded, formula,
     mm <- psclass <- NULL
   }
 
-  if (length(opt.out) == 1L) out <- out[[1]]
+  if (length(opt.out) == 1L) {
+    out <- out[[1L]]
+  }
 
   res <- list(match.matrix = mm,
               subclass = psclass,
               weights = weights,
               obj = opt.out)
 
-  if (verbose) cat("Done.\n")
+  .cat_verbose("Done.\n", verbose = verbose)
 
   class(res) <- "matchit"
 
@@ -436,30 +448,39 @@ matchit2cardinality <-  function(treat, data, discarded, formula,
 ## Function to actually do the matching
 cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weights = NULL,
                                 ratio = 1, focal = NULL, tvals = NULL, solver = "highs",
-                                time = 2*60, verbose = FALSE) {
+                                time = 2 * 60, verbose = FALSE) {
 
   n <- length(treat)
-  if (is.null(tvals)) tvals <- if (is.factor(treat)) levels(treat) else sort(unique(treat))
+  if (is_null(tvals)) tvals <- if (is.factor(treat)) levels(treat) else sort(unique(treat))
   nt <- length(tvals)
 
   #Check inputs
-  if (is.null(s.weights)) s.weights <- rep(1, n)
-  else for (i in tvals) s.weights[treat == i] <- s.weights[treat == i]/mean(s.weights[treat == i])
+  if (is_null(s.weights)) {
+    s.weights <- rep.int(1, n)
+  }
+  else {
+    s.weights <- .make_sum_to_n(s.weights, treat)
+  }
 
-  if (is.null(focal)) focal <- tvals[length(tvals)]
+  if (is_null(focal)) {
+    focal <- tvals[length(tvals)]
+  }
 
   chk::chk_number(time)
   chk::chk_gt(time, 0)
 
   chk::chk_string(solver)
   solver <- match_arg(solver, c("highs", "glpk", "symphony", "gurobi"))
+
   rlang::check_installed(switch(solver, glpk = "Rglpk", symphony = "Rsymphony", gurobi = "gurobi",
                                 highs = "highs"))
 
   #Select match type
-  if (estimand == "ATE") match_type <- "profile_ate"
-  else if (!is.finite(ratio)) match_type <- "profile_att"
-  else match_type <- "cardinality"
+  match_type <- {
+    if (estimand == "ATE") "profile_ate"
+    else if (is.finite(ratio)) "cardinality"
+    else "profile_att"
+  }
 
   #Set objective and constraints
   if (match_type == "profile_ate") {
@@ -468,15 +489,15 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
     #Objective function: total sample size
     O <- c(
       s.weights, #weight for each unit
-      rep(0, nt)       #slack coefs for each sample size (n1, n0)
+      rep.int(0, nt)       #slack coefs for each sample size (n1, n0)
     )
 
     #Constraint matrix
     target.means <- apply(X, 2, wm, w = s.weights)
 
-    C <- matrix(0, nrow = nt * (1 + 2*ncol(X)), ncol = length(O))
-    Crhs <- rep(0, nrow(C))
-    Cdir <- rep("==", nrow(C))
+    C <- matrix(0, nrow = nt * (1 + 2 * ncol(X)), ncol = length(O))
+    Crhs <- rep.int(0, nrow(C))
+    Cdir <- rep.int("==", nrow(C))
 
     for (i in seq_len(nt)) {
       #Num in group i = ni
@@ -484,21 +505,21 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
       C[i, n + i] <- -1
 
       #Cov means must be less than target.means+tols/2
-      r1 <- nt + (i - 1)*2*ncol(X) + 1:ncol(X)
-      C[r1, seq_len(n)] <- t((treat==tvals[i])*s.weights*X)
-      C[r1, n + i] <- -target.means-tols/2
+      r1 <- nt + (i - 1) * 2 * ncol(X) + seq_len(ncol(X))
+      C[r1, seq_len(n)] <- t((treat == tvals[i]) * s.weights * X)
+      C[r1, n + i] <- -target.means - tols / 2
       Cdir[r1] <- "<"
 
       #Cov means must be greater than target.means-tols/2
       r2 <- r1 + ncol(X)
-      C[r2, seq_len(n)] <- t((treat==tvals[i])*s.weights*X)
-      C[r2, n + i] <- -target.means+tols/2
+      C[r2, seq_len(n)] <- t((treat == tvals[i]) * s.weights * X)
+      C[r2, n + i] <- -target.means + tols / 2
       Cdir[r2] <- ">"
     }
 
     #If ratio != 0, constrain n0 to be ratio*n1
     if (nt == 2L && is.finite(ratio)) {
-      C_ratio <- c(rep(0, n), rep(-1, nt))
+      C_ratio <- c(rep.int(0, n), rep.int(-1, nt))
       C_ratio[n + which(tvals == focal)] <- ratio
       C <- rbind(C, C_ratio)
       Crhs <- c(Crhs, 0)
@@ -506,13 +527,13 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
     }
 
     #Coef types
-    types <- c(rep("B", n), #Matching weights
-               rep("C", nt)) #Slack coefs for matched group size
+    types <- c(rep.int("B", n), #Matching weights
+               rep.int("C", nt)) #Slack coefs for matched group size
 
-    lower.bound <- c(rep(0, n),
-                     rep(1, nt))
-    upper.bound <- c(rep(1, n),
-                     rep(Inf, nt))
+    lower.bound <- c(rep.int(0, n),
+                     rep.int(1, nt))
+    upper.bound <- c(rep.int(1, n),
+                     rep.int(Inf, nt))
   }
   else if (match_type == "profile_att") {
     #Find largest control group that matches treated group
@@ -523,17 +544,17 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
 
     #Objective function: size of matched control group
     O <- c(
-      rep(1, n0), #weights for each non-focal unit
-      rep(0, nt - 1)  #slack coef for size of non-focal groups
+      rep.int(1, n0), #weights for each non-focal unit
+      rep.int(0, nt - 1)  #slack coef for size of non-focal groups
     )
 
     #Constraint matrix
-    target.means <- apply(X[treat==focal,,drop=FALSE], 2, wm, w = s.weights[treat==focal])
+    target.means <- apply(X[treat == focal, , drop = FALSE], 2, wm, w = s.weights[treat == focal])
     #One row per constraint, one column per coef
 
-    C <- matrix(0, nrow = (nt - 1) * (1 + 2*ncol(X)), ncol = length(O))
-    Crhs <- rep(0, nrow(C))
-    Cdir <- rep("==", nrow(C))
+    C <- matrix(0, nrow = (nt - 1) * (1 + 2 * ncol(X)), ncol = length(O))
+    Crhs <- rep.int(0, nrow(C))
+    Cdir <- rep.int("==", nrow(C))
 
     for (i in seq_len(nt - 1)) {
       #Num in group i = ni
@@ -541,26 +562,26 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
       C[i, n0 + i] <- -1
 
       #Cov means must be less than target.means+tols
-      r1 <- nt - 1 + (i - 1)*2*ncol(X) + 1:ncol(X)
-      C[r1, seq_len(n0)] <- t((treat[nonf]==tvals_[i])*s.weights[nonf]*X[nonf,,drop = FALSE])
-      C[r1, n0 + i] <- -target.means-tols
+      r1 <- nt - 1 + (i - 1) * 2 * ncol(X) + seq_len(ncol(X))
+      C[r1, seq_len(n0)] <- t((treat[nonf] == tvals_[i]) * s.weights[nonf] * X[nonf, , drop = FALSE])
+      C[r1, n0 + i] <- -target.means - tols
       Cdir[r1] <- "<"
 
       #Cov means must be greater than target.means-tols
       r2 <- r1 + ncol(X)
-      C[r2, seq_len(n0)] <- t((treat[nonf]==tvals_[i])*s.weights[nonf]*X[nonf,,drop = FALSE])
-      C[r2, n0 + i] <- -target.means+tols
+      C[r2, seq_len(n0)] <- t((treat[nonf] == tvals_[i]) * s.weights[nonf] * X[nonf, , drop = FALSE])
+      C[r2, n0 + i] <- -target.means + tols
       Cdir[r2] <- ">"
     }
 
     #Coef types
-    types <- c(rep("B", n0), #Matching weights
-               rep("C", nt - 1))  #Slack for num control matched
+    types <- c(rep.int("B", n0), #Matching weights
+               rep.int("C", nt - 1L))  #Slack for num control matched
 
-    lower.bound <- c(rep(0, n0),
-                     rep(0, nt - 1))
-    upper.bound <- c(rep(1, n0),
-                     rep(Inf, nt - 1))
+    lower.bound <- c(rep.int(0, n0),
+                     rep.int(0, nt - 1L))
+    upper.bound <- c(rep.int(1, n0),
+                     rep.int(Inf, nt - 1L))
   }
   else if (match_type == "cardinality") {
     #True cardinality matching: find largest balanced sample
@@ -573,41 +594,41 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
     )
 
     #Constraint matrix
-    t_combs <- combn(tvals, 2, simplify = FALSE)
+    t_combs <- combn(tvals, 2L, simplify = FALSE)
 
-    C <- matrix(0, nrow = nt + 2*ncol(X)*length(t_combs), ncol = length(O))
-    Crhs <- rep(0, nrow(C))
-    Cdir <- rep("==", nrow(C))
+    C <- matrix(0, nrow = nt + 2 * ncol(X) * length(t_combs), ncol = length(O))
+    Crhs <- rep.int(0, nrow(C))
+    Cdir <- rep.int("==", nrow(C))
 
     for (i in seq_len(nt)) {
       #Num in group i = ni
       C[i, seq_len(n)] <- s.weights * (treat == tvals[i])
-      C[i, n + 1] <- if (tvals[i] == focal) -1 else -ratio
+      C[i, n + 1L] <- if (tvals[i] == focal) -1 else -ratio
     }
 
     for (j in seq_along(t_combs)) {
       t_comb <- t_combs[[j]]
-      if (t_comb[2] == focal) t_comb <- rev(t_comb)
+      if (t_comb[2L] == focal) t_comb <- rev(t_comb)
 
-      r1 <- nt + (j - 1)*2*ncol(X) + 1:ncol(X)
-      C[r1, seq_len(n)] <- t(((treat==t_comb[1]) - (treat==t_comb[2])/ratio)*s.weights*X)
-      C[r1, n + 1] <- -tols
+      r1 <- nt + (j - 1) * 2 * ncol(X) + seq_len(ncol(X))
+      C[r1, seq_len(n)] <- t(((treat == t_comb[1L]) - (treat == t_comb[2L]) / ratio) * s.weights * X)
+      C[r1, n + 1L] <- -tols
       Cdir[r1] <- "<"
 
       r2 <- r1 + ncol(X)
-      C[r2, seq_len(n)] <- t(((treat==t_comb[1]) - (treat==t_comb[2])/ratio)*s.weights*X)
-      C[r2, n + 1] <- tols
+      C[r2, seq_len(n)] <- t(((treat == t_comb[1L]) - (treat == t_comb[2L]) / ratio) * s.weights * X)
+      C[r2, n + 1L] <- tols
       Cdir[r2] <- ">"
     }
 
     #Coef types
-    types <- c(rep("B", n), #Matching weights
-               rep("C", 1)) #Slack coef for treated group size (n1)
+    types <- c(rep.int("B", n), #Matching weights
+               rep.int("C", 1L)) #Slack coef for treated group size (n1)
 
-    lower.bound <- c(rep(0, n),
-                     rep(0, 1))
-    upper.bound <- c(rep(1, n),
-                     rep(min(tabulateC(treat)), 1))
+    lower.bound <- c(rep.int(0, n),
+                     rep.int(0, 1L))
+    upper.bound <- c(rep.int(1, n),
+                     rep.int(min(tabulateC(treat)), 1L))
   }
 
   weights <- NULL
@@ -628,20 +649,20 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
     weights <- round(sol[seq_len(n)])
   }
   else if (match_type %in% c("profile_att")) {
-    weights <- rep(1, n)
+    weights <- rep.int(1, n)
     weights[treat != focal] <- round(sol[seq_len(n0)])
   }
 
   #Make sure sum of weights in both groups is the same (important for exact matching)
   if (match_type == "profile_att" && (is.na(ratio) || ratio != 1)) {
     for (t in setdiff(tvals, focal)) {
-      weights[treat == t] <- weights[treat == t]*sum(weights[treat == focal])/sum(weights[treat == t])
+      weights[treat == t] <- weights[treat == t] * sum(weights[treat == focal]) / sum(weights[treat == t])
     }
   }
   else {
     smallest.group <- tvals[which.min(vapply(tvals, function(t) sum(treat == t), numeric(1L)))]
     for (t in setdiff(tvals, smallest.group)) {
-      weights[treat == t] <- weights[treat == t]*sum(weights[treat == smallest.group])/sum(weights[treat == t])
+      weights[treat == t] <- weights[treat == t] * sum(weights[treat == smallest.group]) / sum(weights[treat == t])
     }
   }
 
@@ -651,7 +672,7 @@ cardinality_matchit <- function(treat, X, estimand = "ATT", tols = .05, s.weight
 cardinality_error_report <- function(out, solver) {
   if (solver == "glpk") {
     if (out$status == 1) {
-      if (all(out$solution == 0)) {
+      if (all_equal_to(out$solution, 0)) {
         .err("the optimization problem may be infeasible. Try increasing the value of `tols`.\nSee `?method_cardinality` for additional details")
       }
       .wrn("the optimizer failed to find an optimal solution in the time alotted. The returned solution may not be optimal.\nSee `?method_cardinality` for additional details")
@@ -685,13 +706,14 @@ cardinality_error_report <- function(out, solver) {
   }
 }
 
-dispatch_optimizer <- function(solver = "glpk", obj, mat, dir, rhs, types, max = TRUE, lb = NULL, ub = NULL, time = NULL, verbose = FALSE) {
+dispatch_optimizer <- function(solver = "highs", obj, mat, dir, rhs, types, max = TRUE,
+                               lb = NULL, ub = NULL, time = NULL, verbose = FALSE) {
   if (solver == "glpk") {
     dir[dir == "="] <- "=="
     opt.out <- Rglpk::Rglpk_solve_LP(obj = obj, mat = mat, dir = dir, rhs = rhs, max = max,
                                      types = types,
                                      # bounds = list(lower = lb, upper = ub), #Spurious warning when using bounds
-                                     control = list(tm_limit = time*1000, verbose = verbose))
+                                     control = list(tm_limit = time * 1000, verbose = verbose))
   }
   else if (solver == "symphony") {
     dir[dir == "<"] <- "<="
