@@ -65,7 +65,7 @@
 #' place when `distance` corresponds to a propensity score (e.g., for
 #' caliper matching or to discard units for common support). If specified, the
 #' distance measure will not be used in matching.
-#' @param antiexact for which variables ant-exact matching should take place.
+#' @param antiexact for which variables anti-exact matching should take place.
 #' Anti-exact matching is processed using \pkgfun{optmatch}{antiExactMatch}.
 #' @param discard a string containing a method for discarding units outside a
 #' region of common support. Only allowed when `distance` is not
@@ -88,7 +88,7 @@
 #' Allowed arguments include `tol` and `solver`. See the
 #' \pkgfun{optmatch}{fullmatch} documentation for details. In general, `tol`
 #' should be set to a low number (e.g., `1e-7`) to get a more precise
-#' solution.
+#' solution (default is `1e-3`).
 #'
 #' The arguments `replace`, `caliper`, and `m.order` are ignored with a warning.
 #'
@@ -148,13 +148,11 @@
 #' (`estimand = "ATT"`) or treated units are selected to be matched with
 #' control units (`estimand = "ATC"`). The "focal" group (e.g., the
 #' treated units for the ATT) is typically made to be the smaller treatment
-#' group, and a warning will be thrown if it is not set that way unless
-#' `replace = TRUE`. Setting `estimand = "ATC"` is equivalent to
+#' group, and a warning will be thrown if it is not set that. Setting `estimand = "ATC"` is equivalent to
 #' swapping all treated and control labels for the treatment variable. When
 #' `estimand = "ATC"`, the `match.matrix` component of the output
 #' will have the names of the control units as the rownames and be filled with
-#' the names of the matched treated units (opposite to when `estimand =
-#' "ATT"`). Note that the argument supplied to `estimand` doesn't
+#' the names of the matched treated units (opposite to when `estimand = "ATT"`). Note that the argument supplied to `estimand` doesn't
 #' necessarily correspond to the estimand actually targeted; it is merely a
 #' switch to trigger which treatment group is considered "focal".
 #'
@@ -166,7 +164,8 @@
 #' treated units to receive `ratio` matches, the arguments to
 #' `max.controls` and `min.controls` can be specified to control the
 #' maximum and minimum number of matches each treated unit can have.
-#' `ratio` controls how many total control units will be matched: `n1 * ratio` control units will be matched, where `n1` is the number of
+#' `ratio` controls how many total control units will be matched: `n1 * ratio` control
+#' units will be matched, where `n1` is the number of
 #' treated units, yielding the same total number of matched controls as fixed
 #' ratio matching does.
 #'
@@ -200,6 +199,8 @@
 #' may also let huge, infeasible problems get through and potentially take a
 #' long time or crash R. See \pkgfun{optmatch}{setMaxProblemSize} for more details.
 #'
+#' A preprocessing algorithm describe by Sävje (2020; \doi{10.1214/19-STS739}) is used to improve the speed of the matching when 1:1 matching on a propensity score. It does so by adding an additional constraint that guarantees a solution as optimal as the solution that would have been found without the constraint, and that constraint often dramatically reduces the size of the matching problem at no cost. However, this may introduce differences between the results obtained by *MatchIt* and by *optmatch*, though such differences will shrink when smaller values of `tol` are used.
+#'
 #' @seealso [matchit()] for a detailed explanation of the inputs and outputs of
 #' a call to `matchit()`.
 #'
@@ -225,16 +226,20 @@
 #' data("lalonde")
 #'
 #' #1:1 optimal PS matching with exact matching on race
-#' m.out1 <- matchit(treat ~ age + educ + race + nodegree +
-#'                     married + re74 + re75, data = lalonde,
-#'                   method = "optimal", exact = ~race)
+#' m.out1 <- matchit(treat ~ age + educ + race +
+#'                     nodegree + married + re74 + re75,
+#'                   data = lalonde,
+#'                   method = "optimal",
+#'                   exact = ~race)
 #' m.out1
 #' summary(m.out1)
 #'
 #' #2:1 optimal matching on the scaled Euclidean distance
-#' m.out2 <- matchit(treat ~ age + educ + race + nodegree +
-#'                     married + re74 + re75, data = lalonde,
-#'                   method = "optimal", ratio = 2,
+#' m.out2 <- matchit(treat ~ age + educ + race +
+#'                     nodegree + married + re74 + re75,
+#'                   data = lalonde,
+#'                   method = "optimal",
+#'                   ratio = 2,
 #'                   distance = "scaled_euclidean")
 #' m.out2
 #' summary(m.out2, un = FALSE)
@@ -244,20 +249,13 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
                             ratio = 1, s.weights = NULL, caliper = NULL,
                             mahvars = NULL, exact = NULL,
                             estimand = "ATT", verbose = FALSE,
-                            is.full.mahalanobis,  antiexact = NULL, ...) {
+                            is.full.mahalanobis, antiexact = NULL, ...) {
 
   rlang::check_installed("optmatch")
 
-  if (verbose) cat("Optimal matching... \n")
-
-  A <- list(...)
-  pm.args <- c("tol", "solver")
-  A[!names(A) %in% pm.args] <- NULL
-
-  #Set max problem size to Inf and return to original value after match
-  omps <- getOption("optmatch_max_problem_size")
-  on.exit(options(optmatch_max_problem_size = omps))
-  options(optmatch_max_problem_size = Inf)
+  .args <- c("tol", "solver")
+  A <- ...mget(.args)
+  A[lengths(A) == 0L] <- NULL
 
   estimand <- toupper(estimand)
   estimand <- match_arg(estimand, c("ATT", "ATC"))
@@ -272,17 +270,17 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
 
   treat_ <- setNames(as.integer(treat[!discarded] == focal), names(treat)[!discarded])
 
-  # if (!is.null(data)) data <- data[!discarded,]
+  # if (is_not_null(data)) data <- data[!discarded,]
 
   if (is.full.mahalanobis) {
-    if (length(attr(terms(formula, data = data), "term.labels")) == 0) {
+    if (is_null(attr(terms(formula, data = data), "term.labels"))) {
       .err(sprintf("covariates must be specified in the input formula when `distance = \"%s\"`",
                    attr(is.full.mahalanobis, "transform")))
     }
     mahvars <- formula
   }
 
-  if (!is.null(caliper)) {
+  if (is_not_null(caliper)) {
     .wrn("calipers are currently not compatible with `method = \"optimal\"` and will be ignored")
     caliper <- NULL
   }
@@ -290,56 +288,62 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
   min.controls <- attr(ratio, "min.controls")
   max.controls <- attr(ratio, "max.controls")
 
-  if (is.null(max.controls)) {
+  if (is_null(max.controls)) {
     min.controls <- max.controls <- ratio
   }
 
   #Exact matching strata
-  if (!is.null(exact)) {
+  if (is_not_null(exact)) {
     ex <- factor(exactify(model.frame(exact, data = data),
                           sep = ", ", include_vars = TRUE)[!discarded])
 
-    cc <- intersect(as.integer(ex)[treat_==1], as.integer(ex)[treat_==0])
-    if (length(cc) == 0) .err("No matches were found")
+    cc <- Reduce("intersect", lapply(unique(treat_), function(t) unclass(ex)[treat_ == t]))
 
-    e_ratios <- vapply(levels(ex), function(e) sum(treat_[ex == e] == 0)/sum(treat_[ex == e] == 1), numeric(1L))
+    if (is_null(cc)) {
+      .err("no matches were found")
+    }
+
+    e_ratios <- vapply(levels(ex), function(e) {
+      sum(treat_[ex == e] == 0) / sum(treat_[ex == e] == 1)
+    }, numeric(1L))
 
     if (any(e_ratios < 1)) {
-      .wrn(sprintf("Fewer %s units than %s units in some `exact` strata; not all %s units will get a match",
-                      tc[2], tc[1], tc[1]))
+      .wrn(sprintf("fewer %s units than %s units in some `exact` strata; not all %s units will get a match",
+                   tc[2L], tc[1L], tc[1L]))
     }
+
     if (ratio > 1 && any(e_ratios < ratio)) {
       if (ratio == max.controls)
-        .wrn(sprintf("Not all %s units will get %s matches",
-                        tc[1], ratio))
+        .wrn(sprintf("not all %s units will get %s matches",
+                     tc[1L], ratio))
       else
-        .wrn(sprintf("Not enough %s units for an average of %s matches per %s unit in all `exact` strata",
-                        tc[2], ratio, tc[1]))
+        .wrn(sprintf("not enough %s units for an average of %s matches per %s unit in all `exact` strata",
+                     tc[2L], ratio, tc[1L]))
     }
   }
   else {
-    ex <- factor(rep("_", length(treat_)), levels = "_")
+    ex <- gl(1, length(treat_), labels = "_")
     cc <- 1
 
-    e_ratios <- setNames(sum(treat_ == 0)/sum(treat_ == 1), levels(ex))
+    e_ratios <- setNames(sum(treat_ == 0) / sum(treat_ == 1), levels(ex))
 
     if (e_ratios < 1) {
-      .wrn(sprintf("Fewer %s units than %s units; not all %s units will get a match",
-                      tc[2], tc[1], tc[1]))
+      .wrn(sprintf("fewer %s units than %s units; not all %s units will get a match",
+                   tc[2L], tc[1L], tc[1L]))
     }
     else if (e_ratios < ratio) {
       if (ratio == max.controls)
-        .wrn(sprintf("Not all %s units will get %s matches",
-                        tc[1], ratio))
+        .wrn(sprintf("not all %s units will get %s matches",
+                     tc[1L], ratio))
       else
-        .wrn(sprintf("Not enough %s units for an average of %s matches per %s unit",
-                        tc[2], ratio, tc[1]))
+        .wrn(sprintf("not enough %s units for an average of %s matches per %s unit",
+                     tc[2L], ratio, tc[1L]))
     }
   }
 
   #Create distance matrix; note that Mahalanobis distance computed using entire
   #sample (minus discarded), like method2nearest, as opposed to within exact strata, like optmatch.
-  if (!is.null(mahvars)) {
+  if (is_not_null(mahvars)) {
     transform <- if (is.full.mahalanobis) attr(is.full.mahalanobis, "transform") else "mahalanobis"
     mahcovs <- transform_covariates(mahvars, data = data, method = transform,
                                     s.weights = s.weights, treat = treat,
@@ -354,17 +358,33 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
   }
 
   #Transpose distance mat as needed
-  if (focal == 0) mo <- t(mo)
+  if (focal == 0) {
+    mo <- t(mo)
+  }
 
   #Remove discarded units from distance mat
   mo <- mo[!discarded[treat == focal], !discarded[treat != focal], drop = FALSE]
   dimnames(mo) <- list(names(treat_)[treat_ == 1], names(treat_)[treat_ == 0])
 
-  mo <- optmatch::match_on(mo, data = data[!discarded,, drop = FALSE])
+  mo <- optmatch::match_on(mo, data = as.data.frame(data)[!discarded, , drop = FALSE])
   mo <- optmatch::as.InfinitySparseMatrix(mo)
 
+  if (is_null(mahvars) && !is.matrix(distance) && nlevels(ex) == 1L &&
+      ratio == 1 && max.controls == 1) {
+    .cat_verbose("Preprocessing to reduce problem size...\n", verbose = verbose)
+
+    #Preprocess by pruning unnecessary edges as in Sävje (2020) https://doi.org/10.1214/19-STS699
+    keep <- preprocess_matchC(treat_, distance[!discarded])
+
+    if (length(keep) < length(mo)) {
+      mo <- .subset_infsm(mo, keep)
+    }
+  }
+
+  .cat_verbose("Optimal matching...\n", verbose = verbose)
+
   #Process antiexact
-  if (!is.null(antiexact)) {
+  if (is_not_null(antiexact)) {
     antiexactcovs <- model.frame(antiexact, data)
     for (i in seq_len(ncol(antiexactcovs))) {
       mo <- mo + optmatch::antiExactMatch(antiexactcovs[[i]][!discarded], z = treat_)
@@ -372,23 +392,28 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
   }
 
   #Initialize pair membership; must include names
-  pair <- setNames(rep(NA_character_, length(treat)), names(treat))
+  pair <- rep_with(NA_character_, treat)
   p <- setNames(vector("list", nlevels(ex)), levels(ex))
 
   t_df <- data.frame(treat_)
 
   for (e in levels(ex)[cc]) {
-    if (nlevels(ex) > 1) {
-      if (verbose) {
-        cat(sprintf("Matching subgroup %s/%s: %s...\n",
-                    match(e, levels(ex)[cc]), length(cc), e))
-      }
-      mo_ <- mo[ex[treat_==1] == e, ex[treat_==0] == e]
-    }
-    else mo_ <- mo
+    if (nlevels(ex) > 1L) {
+      .cat_verbose(sprintf("Matching subgroup %s/%s: %s...\n",
+                           match(e, levels(ex)[cc]), length(cc), e),
+                   verbose = verbose)
 
-    if (any(dim(mo_) == 0) || !any(is.finite(mo_))) next
-    else if (all(dim(mo_) == 1) && all(is.finite(mo_))) {
+      mo_ <- mo[ex[treat_ == 1] == e, ex[treat_ == 0] == e]
+    }
+    else {
+      mo_ <- mo
+    }
+
+    if (any(dim(mo_) == 0) || !any(is.finite(mo_))) {
+      next
+    }
+
+    if (all_equal_to(dim(mo_), 1) && all(is.finite(mo_))) {
       pair[ex == e] <- paste(1, e, sep = "|")
       next
     }
@@ -412,21 +437,24 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
       max.controls_ <- max.controls
     }
 
-    matchit_try({
-      p[[e]] <- do.call(optmatch::fullmatch,
-                        c(list(mo_,
-                               mean.controls = ratio_,
-                               min.controls = min.controls_,
-                               max.controls = max.controls_,
-                               data = t_df[ex == e,, drop = FALSE]), #just to get rownames; not actually used in matching
-                          A))
-    }, from = "optmatch")
+    A$x <- mo_
+    A$mean.controls <- ratio_
+    A$min.controls <- min.controls_
+    A$max.controls <- max.controls_
+    A$data <- t_df[ex == e, , drop = FALSE] #just to get rownames; not actually used in matching
+
+    rlang::with_options({
+      matchit_try({
+        p[[e]] <- do.call(optmatch::fullmatch, A)
+      }, from = "optmatch")
+    }, optmatch_max_problem_size = Inf)
 
     pair[names(p[[e]])[!is.na(p[[e]])]] <- paste(as.character(p[[e]][!is.na(p[[e]])]), e, sep = "|")
   }
 
-  if (all(is.na(pair))) .err("No matches were found")
-  if (length(p) == 1) p <- p[[1]]
+  if (length(p) == 1L) {
+    p <- p[[1L]]
+  }
 
   psclass <- factor(pair)
   levels(psclass) <- seq_len(nlevels(psclass))
@@ -434,7 +462,7 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
 
   mm <- nummm2charmm(subclass2mmC(psclass, treat, focal), treat)
 
-  if (verbose) cat("Calculating matching weights... ")
+  .cat_verbose("Calculating matching weights...", verbose = verbose)
 
   ## calculate weights and return the results
   res <- list(match.matrix = mm,
@@ -442,8 +470,17 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
               weights = get_weights_from_subclass(psclass, treat, estimand),
               obj = p)
 
-  if (verbose) cat("Done.\n")
+  .cat_verbose("Done.\n", verbose = verbose)
 
   class(res) <- "matchit"
   res
 }
+
+#Subset InfinitySparseMatrix using vector indices
+.subset_infsm <- function(y, ss) {
+  y@.Data <- y[ss]
+  y@cols <- y@cols[ss]
+  y@rows <- y@rows[ss]
+
+  y
+}
