@@ -122,19 +122,24 @@
 #' data("lalonde")
 #'
 #' m.out <- matchit(treat ~ age + educ + married +
-#'                    race + re74, data = lalonde,
+#'                    race + re74,
+#'                  data = lalonde,
 #'                  method = "nearest")
-#' plot(m.out, type = "qq", interactive = FALSE,
+#' plot(m.out, type = "qq",
+#'      interactive = FALSE,
 #'      which.xs = ~age + educ + re74)
 #' plot(m.out, type = "histogram")
 #'
 #' s.out <- matchit(treat ~ age + educ + married +
 #'                    race + nodegree + re74 + re75,
-#'                  data = lalonde, method = "subclass")
-#' plot(s.out, type = "density", interactive = FALSE,
+#'                  data = lalonde,
+#'                  method = "subclass")
+#' plot(s.out, type = "density",
+#'      interactive = FALSE,
 #'      which.xs = ~age + educ + re74,
 #'      subclass = 3)
-#' plot(s.out, type = "jitter", interactive = FALSE)
+#' plot(s.out, type = "jitter",
+#'      interactive = FALSE)
 #'
 
 #' @exportS3Method plot matchit
@@ -149,16 +154,16 @@ plot.matchit <- function(x, type = "qq", interactive = TRUE, which.xs = NULL, da
                     which.xs = which.xs, data = data, ...)
   }
   else if (type == "jitter") {
-    if (is.null(x$distance)) {
-      .err("`type = \"jitter\"` cannot be used if a distance measure is not estimated or supplied. No plots generated")
+    if (is_null(x$distance)) {
+      .err('`type = "jitter"` cannot be used if a distance measure is not estimated or supplied. No plots generated')
     }
-    jitter.pscore(x, interactive = interactive,...)
+    jitter_pscore(x, interactive = interactive, ...)
   }
   else if (type == "histogram") {
-    if (is.null(x$distance)) {
-      .err("`type = \"hist\"` cannot be used if a distance measure is not estimated or supplied. No plots generated")
+    if (is_null(x$distance)) {
+      .err('`type = "hist"` cannot be used if a distance measure is not estimated or supplied. No plots generated')
     }
-    hist.pscore(x,...)
+    hist_pscore(x, ...)
   }
   invisible(x)
 }
@@ -167,15 +172,16 @@ plot.matchit <- function(x, type = "qq", interactive = TRUE, which.xs = NULL, da
 #' @rdname plot.matchit
 plot.matchit.subclass <- function(x, type = "qq", interactive = TRUE, which.xs = NULL, subclass, ...) {
   choice.menu <- function(choices, question) {
-    k <- length(choices)-1
+    k <- length(choices) - 1
     Choices <- data.frame(choices)
     row.names(Choices) <- 0:k
     names(Choices) <- "Choices"
-    print.data.frame(Choices, right=FALSE)
+    print.data.frame(Choices, right = FALSE)
     ans <- readline(question)
+
     while (!ans %in% 0:k) {
       message("Not valid -- please pick one of the choices")
-      print.data.frame(Choices, right=FALSE)
+      print.data.frame(Choices, right = FALSE)
       ans <- readline(question)
     }
 
@@ -192,15 +198,22 @@ plot.matchit.subclass <- function(x, type = "qq", interactive = TRUE, which.xs =
     #If subclass = NULL, if interactive, use to choose subclass, else display aggregate across subclass
 
     subclasses <- levels(x$subclass)
-    miss.sub <- missing(subclass) || is.null(subclass)
-    if (miss.sub || isFALSE(subclass)) which.subclass <- NULL
-    else if (isTRUE(subclass)) which.subclass <- subclasses
-    else if (!is.atomic(subclass) || !all(subclass %in% seq_along(subclasses))) {
+    miss.sub <- missing(subclass) || is_null(subclass)
+
+    if (miss.sub || isFALSE(subclass)) {
+      which.subclass <- NULL
+    }
+    else if (isTRUE(subclass)) {
+      which.subclass <- subclasses
+    }
+    else if (is.atomic(subclass) && all(subclass %in% seq_along(subclasses))) {
+      which.subclass <- subclasses[subclass]
+    }
+    else {
       .err("`subclass` should be `TRUE`, `FALSE`, or a vector of subclass indices for which subclass balance is to be displayed")
     }
-    else which.subclass <- subclasses[subclass]
 
-    if (!is.null(which.subclass)) {
+    if (is_not_null(which.subclass)) {
       matchit.covplot.subclass(x, type = type, which.subclass = which.subclass,
                                interactive = interactive, which.xs = which.xs, ...)
     }
@@ -225,17 +238,17 @@ plot.matchit.subclass <- function(x, type = "qq", interactive = TRUE, which.xs =
       matchit.covplot(x, type = type, interactive = interactive, which.xs = which.xs, ...)
     }
   }
-  else if (type=="jitter") {
-    if (is.null(x$distance)) {
-      .err("`type = \"jitter\"` cannot be used when no distance variable was estimated or supplied")
+  else if (type == "jitter") {
+    if (is_null(x$distance)) {
+      .err('`type = "jitter"` cannot be used when no distance variable was estimated or supplied')
     }
-    jitter.pscore(x, interactive = interactive, ...)
+    jitter_pscore(x, interactive = interactive, ...)
   }
   else if (type == "histogram") {
-    if (is.null(x$distance)) {
-      .err("`type = \"histogram\"` cannot be used when no distance variable was estimated or supplied")
+    if (is_null(x$distance)) {
+      .err('`type = "histogram"` cannot be used when no distance variable was estimated or supplied')
     }
-    hist.pscore(x,...)
+    hist_pscore(x, ...)
   }
   invisible(x)
 }
@@ -243,25 +256,26 @@ plot.matchit.subclass <- function(x, type = "qq", interactive = TRUE, which.xs =
 ## plot helper functions
 matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs = NULL, data = NULL, ...) {
 
-  if (is.null(which.xs)) {
-    if (length(object$X) == 0) {
+  if (is_null(which.xs)) {
+    if (is_null(object$X)) {
       .wrn("No covariates to plot")
       return(invisible(NULL))
     }
+
     X <- object$X
 
-    if (!is.null(object$exact)) {
+    if (is_not_null(object$exact)) {
       Xexact <- model.frame(object$exact, data = object$X)
       X <- cbind(X, Xexact[setdiff(names(Xexact), names(X))])
     }
 
-    if (!is.null(object$mahvars)) {
+    if (is_not_null(object$mahvars)) {
       Xmahvars <- model.frame(object$mahvars, data = object$X)
       X <- cbind(X, Xmahvars[setdiff(names(Xmahvars), names(X))])
     }
   }
   else {
-    if (!is.null(data)) {
+    if (is_not_null(data)) {
       if (!is.data.frame(data) || nrow(data) != length(object$treat)) {
         .err("`data` must be a data frame with as many rows as there are units in the supplied `matchit` object")
       }
@@ -271,19 +285,19 @@ matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs =
       data <- object$X
     }
 
-    if (!is.null(object$exact)) {
+    if (is_not_null(object$exact)) {
       Xexact <- model.frame(object$exact, data = object$X)
       data <- cbind(data, Xexact[setdiff(names(Xexact), names(data))])
     }
 
-    if (!is.null(object$mahvars)) {
+    if (is_not_null(object$mahvars)) {
       Xmahvars <- model.frame(object$mahvars, data = object$X)
       data <- cbind(data, Xmahvars[setdiff(names(Xmahvars), names(data))])
     }
 
     if (is.character(which.xs)) {
-      if (!all(which.xs %in% names(data))) {
-        .err("All variables in `which.xs` must be in the supplied `matchit` object or in `data`")
+      if (!all(hasName(data, which.xs))) {
+        .err("all variables in `which.xs` must be in the supplied `matchit` object or in `data`")
       }
       X <- data[which.xs]
     }
@@ -302,15 +316,18 @@ matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs =
 
     k <- ncol(X)
     for (i in seq_len(k)) {
-      if (anyNA(X[[i]]) || (is.numeric(X[[i]]) && any(!is.finite(X[[i]])))) {
+      if (anyNA(X[[i]]) || (is.numeric(X[[i]]) && !all(is.finite(X[[i]])))) {
         covariates.with.missingness <- names(X)[i:k][vapply(i:k, function(j) anyNA(X[[j]]) ||
-                                                                          (is.numeric(X[[j]]) &&
-                                                                             any(!is.finite(X[[j]]))),
-                                                                        logical(1L))]
+                                                              (is.numeric(X[[j]]) &&
+                                                                 !all(is.finite(X[[j]]))),
+                                                            logical(1L))]
         .err(paste0("Missing and non-finite values are not allowed in the covariates named in `which.xs`. Variables with missingness or non-finite values:\n\t",
-                    paste(covariates.with.missingness, collapse = ", ")), tidy = FALSE)
+                    toString(covariates.with.missingness)), tidy = FALSE)
+      }
+
+      if (is.character(X[[i]])) {
+        X[[i]] <- factor(X[[i]])
       }
-      if (is.character(X[[i]])) X[[i]] <- factor(X[[i]])
     }
   }
 
@@ -318,9 +335,13 @@ matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs =
 
   t <- object$treat
 
-  sw <- if (is.null(object$s.weights)) rep(1, length(t)) else object$s.weights
+  sw <- {
+    if (is_null(object$s.weights)) rep.int(1, length(t))
+    else object$s.weights
+  }
+
   w <- object$weights * sw
-  if (is.null(w)) w <- rep(1, length(t))
+  if (is_null(w)) w <- rep.int(1, length(t))
 
   w <- .make_sum_to_1(w, by = t)
   sw <- .make_sum_to_1(sw, by = t)
@@ -329,7 +350,7 @@ matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs =
     varnames <- names(X)
   }
   else {
-    X <- get.covs.matrix(data = X)
+    X <- get_covs_matrix(data = X)
     varnames <- colnames(X)
   }
 
@@ -338,45 +359,45 @@ matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs =
 
   oma <- c(2.25, 0, 3.75, 1.5)
   if (type == "qq") {
-    opar <- par(mfrow = c(3, 3), mar = rep.int(1/2, 4), oma = oma)
+    opar <- par(mfrow = c(3, 3), mar = rep.int(.5, 4L), oma = oma)
   }
   else if (type %in% c("ecdf", "density")) {
-    opar <- par(mfrow = c(3, 3), mar = c(1.5,.5,1.5,.5), oma = oma)
+    opar <- par(mfrow = c(3, 3), mar = c(1.5, .5, 1.5, .5), oma = oma)
   }
 
   for (i in seq_along(varnames)){
-    x <- if (type == "density") X[[i]] else X[,i]
+    x <- if (type == "density") X[[i]] else X[, i]
 
     plot.new()
 
-    if (((i-1)%%3)==0) {
+    if (((i - 1) %% 3) == 0) {
 
       if (type == "qq") {
         htext <- "eQQ Plots"
-        mtext(htext, 3, 2, TRUE, 0.5, cex=1.1, font = 2)
-        mtext("All", 3, .25, TRUE, 0.5, cex=1, font = 1)
-        mtext("Matched", 3, .25, TRUE, 0.83, cex=1, font = 1)
-        mtext("Control Units", 1, 0, TRUE, 2/3, cex=1, font = 1)
-        mtext("Treated Units", 4, 0, TRUE, 0.5, cex=1, font = 1)
+        mtext(htext, 3, 2, TRUE, 0.5, cex = 1.1, font = 2)
+        mtext("All", 3, .25, TRUE, 0.5, cex = 1, font = 1)
+        mtext("Matched", 3, .25, TRUE, 0.83, cex = 1, font = 1)
+        mtext("Control Units", 1, 0, TRUE, 2 / 3, cex = 1, font = 1)
+        mtext("Treated Units", 4, 0, TRUE, 0.5, cex = 1, font = 1)
       }
       else if (type == "ecdf") {
         htext <- "eCDF Plots"
-        mtext(htext, 3, 2, TRUE, 0.5, cex=1.1, font = 2)
-        mtext("All", 3, .25, TRUE, 0.5, cex=1, font = 1)
-        mtext("Matched", 3, .25, TRUE, 0.83, cex=1, font = 1)
+        mtext(htext, 3, 2, TRUE, 0.5, cex = 1.1, font = 2)
+        mtext("All", 3, .25, TRUE, 0.5, cex = 1, font = 1)
+        mtext("Matched", 3, .25, TRUE, 0.83, cex = 1, font = 1)
       }
       else if (type == "density") {
         htext <- "Density Plots"
-        mtext(htext, 3, 2, TRUE, 0.5, cex=1.1, font = 2)
-        mtext("All", 3, .25, TRUE, 0.5, cex=1, font = 1)
-        mtext("Matched", 3, .25, TRUE, 0.83, cex=1, font = 1)
+        mtext(htext, 3, 2, TRUE, 0.5, cex = 1.1, font = 2)
+        mtext("All", 3, .25, TRUE, 0.5, cex = 1, font = 1)
+        mtext("Matched", 3, .25, TRUE, 0.83, cex = 1, font = 1)
       }
 
     }
 
     par(usr = c(0, 1, 0, 1))
     l.wid <- strwidth(varnames, "user")
-    cex.labels <- max(0.75, min(1.45, 0.85/max(l.wid)))
+    cex.labels <- max(0.75, min(1.45, 0.85 / max(l.wid)))
     text(0.5, 0.5, varnames[i], cex = cex.labels)
 
     if (type == "qq") {
@@ -391,6 +412,7 @@ matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs =
 
     devAskNewPage(ask = interactive)
   }
+
   devAskNewPage(ask = FALSE)
 
   invisible(NULL)
@@ -399,25 +421,27 @@ matchit.covplot <- function(object, type = "qq", interactive = TRUE, which.xs =
 matchit.covplot.subclass <- function(object, type = "qq", which.subclass = NULL,
                                      interactive = TRUE, which.xs = NULL, data = NULL, ...) {
 
-  if (is.null(which.xs)) {
-    if (length(object$X) == 0) {
-      .wrn("No covariates to plot")
+  if (is_null(which.xs)) {
+    if (is_null(object$X)) {
+      .wrn("no covariates to plot")
+
       return(invisible(NULL))
     }
+
     X <- object$X
 
-    if (!is.null(object$exact)) {
+    if (is_not_null(object$exact)) {
       Xexact <- model.frame(object$exact, data = object$X)
       X <- cbind(X, Xexact[setdiff(names(Xexact), names(X))])
     }
 
-    if (!is.null(object$mahvars)) {
+    if (is_not_null(object$mahvars)) {
       Xmahvars <- model.frame(object$mahvars, data = object$X)
       X <- cbind(X, Xmahvars[setdiff(names(Xmahvars), names(X))])
     }
   }
   else {
-    if (!is.null(data)) {
+    if (is_not_null(data)) {
       if (!is.data.frame(data) || nrow(data) != length(object$treat)) {
         .err("`data` must be a data frame with as many rows as there are units in the supplied `matchit` object")
       }
@@ -427,19 +451,19 @@ matchit.covplot.subclass <- function(object, type = "qq", which.subclass = NULL,
       data <- object$X
     }
 
-    if (!is.null(object$exact)) {
+    if (is_not_null(object$exact)) {
       Xexact <- model.frame(object$exact, data = object$X)
       data <- cbind(data, Xexact[setdiff(names(Xexact), names(data))])
     }
 
-    if (!is.null(object$mahvars)) {
+    if (is_not_null(object$mahvars)) {
       Xmahvars <- model.frame(object$mahvars, data = object$X)
       data <- cbind(data, Xmahvars[setdiff(names(Xmahvars), names(data))])
     }
 
     if (is.character(which.xs)) {
-      if (!all(which.xs %in% names(data))) {
-        .err("All variables in `which.xs` must be in the supplied `matchit` object or in `data`")
+      if (!all(hasName(data, which.xs))) {
+        .err("all variables in `which.xs` must be in the supplied `matchit` object or in `data`")
       }
       X <- data[which.xs]
     }
@@ -447,9 +471,7 @@ matchit.covplot.subclass <- function(object, type = "qq", which.subclass = NULL,
       which.xs <- update(terms(which.xs, data = data), NULL ~ .)
       X <- model.frame(which.xs, data, na.action = "na.pass")
 
-      if (anyNA(X)) {
-        .err("Missing values are not allowed in the covariates named in `which.xs`")
-      }
+      chk::chk_not_any_na(X, "the covariates named in `which.xs`")
     }
     else {
       .err("`which.xs` must be supplied as a character vector of names or a one-sided formula")
@@ -457,24 +479,27 @@ matchit.covplot.subclass <- function(object, type = "qq", which.subclass = NULL,
   }
 
   chars.in.X <- vapply(X, is.character, logical(1L))
-  X[chars.in.X] <- lapply(X[chars.in.X], factor)
+  for (i in which(chars.in.X)) {
+    X[[i]] <- factor(X[[i]])
+  }
 
   X <- droplevels(X)
 
   t <- object$treat
 
   if (!is.atomic(which.subclass)) {
-    .err("The argument to `subclass` must be NULL or the indices of the subclasses for which to display covariate distributions")
+    .err("the argument to `subclass` must be `NULL` or the indices of the subclasses for which to display covariate distributions")
   }
+
   if (!all(which.subclass %in% object$subclass[!is.na(object$subclass)])) {
-    .err("The argument supplied to `subclass` is not the index of any subclass in the matchit object")
+    .err("the argument supplied to `subclass` is not the index of any subclass in the `matchit` object")
   }
 
   if (type == "density") {
     varnames <- names(X)
   }
   else {
-    X <- get.covs.matrix(data = X)
+    X <- get_covs_matrix(data = X)
     varnames <- colnames(X)
   }
 
@@ -485,45 +510,49 @@ matchit.covplot.subclass <- function(object, type = "qq", which.subclass = NULL,
 
   for (s in which.subclass) {
     if (type == "qq") {
-      opar <- par(mfrow = c(3, 3), mar = rep.int(1/2, 4), oma = oma)
+      opar <- par(mfrow = c(3, 3), mar = rep.int(.5, 4), oma = oma)
     }
     else if (type %in% c("ecdf", "density")) {
-      opar <- par(mfrow = c(3, 3), mar = c(1.5,.5,1.5,.5), oma = oma)
+      opar <- par(mfrow = c(3, 3), mar = c(1.5, .5, 1.5, .5), oma = oma)
     }
 
-    sw <- if (is.null(object$s.weights)) rep(1, length(t)) else object$s.weights
-    w <- sw*(!is.na(object$subclass) & object$subclass == s)
+    sw <- {
+      if (is_null(object$s.weights)) rep.int(1, length(t))
+      else object$s.weights
+    }
+
+    w <- sw * (!is.na(object$subclass) & object$subclass == s)
 
     w <- .make_sum_to_1(w, by = t)
     sw <- .make_sum_to_1(sw, by = t)
 
     for (i in seq_along(varnames)){
 
-      x <- if (type == "density") X[[i]] else X[,i]
+      x <- switch(type, "density" = X[[i]], X[, i])
 
       plot.new()
 
-      if (((i-1)%%3)==0) {
+      if (((i - 1) %% 3) == 0) {
 
         if (type == "qq") {
-          htext <- paste0("eQQ Plots (Subclass ", s,")")
-          mtext(htext, 3, 2, TRUE, 0.5, cex=1.1, font = 2)
-          mtext("All", 3, .25, TRUE, 0.5, cex=1, font = 1)
-          mtext("Matched", 3, .25, TRUE, 0.83, cex=1, font = 1)
-          mtext("Control Units", 1, 0, TRUE, 2/3, cex=1, font = 1)
-          mtext("Treated Units", 4, 0, TRUE, 0.5, cex=1, font = 1)
+          htext <- sprintf("eQQ Plots (Subclass %s)", s)
+          mtext(htext, 3, 2, TRUE, 0.5, cex = 1.1, font = 2)
+          mtext("All", 3, .25, TRUE, 0.5, cex = 1, font = 1)
+          mtext("Matched", 3, .25, TRUE, 0.83, cex = 1, font = 1)
+          mtext("Control Units", 1, 0, TRUE, 2 / 3, cex = 1, font = 1)
+          mtext("Treated Units", 4, 0, TRUE, 0.5, cex = 1, font = 1)
         }
         else if (type == "ecdf") {
-          htext <- paste0("eCDF Plots (Subclass ", s,")")
-          mtext(htext, 3, 2, TRUE, 0.5, cex=1.1, font = 2)
-          mtext("All", 3, .25, TRUE, 0.5, cex=1, font = 1)
-          mtext("Matched", 3, .25, TRUE, 0.83, cex=1, font = 1)
+          htext <- sprintf("eCDF Plots (Subclass %s)", s)
+          mtext(htext, 3, 2, TRUE, 0.5, cex = 1.1, font = 2)
+          mtext("All", 3, .25, TRUE, 0.5, cex = 1, font = 1)
+          mtext("Matched", 3, .25, TRUE, 0.83, cex = 1, font = 1)
         }
         else if (type == "density") {
-          htext <- paste0("Density Plots (Subclass ", s,")")
-          mtext(htext, 3, 2, TRUE, 0.5, cex=1.1, font = 2)
-          mtext("All", 3, .25, TRUE, 0.5, cex=1, font = 1)
-          mtext("Matched", 3, .25, TRUE, 0.83, cex=1, font = 1)
+          htext <- sprintf("Density Plots (Subclass %s)", s)
+          mtext(htext, 3, 2, TRUE, 0.5, cex = 1.1, font = 2)
+          mtext("All", 3, .25, TRUE, 0.5, cex = 1, font = 1)
+          mtext("Matched", 3, .25, TRUE, 0.83, cex = 1, font = 1)
         }
 
       }
@@ -531,7 +560,7 @@ matchit.covplot.subclass <- function(object, type = "qq", which.subclass = NULL,
       #Empty plot with variable name
       par(usr = c(0, 1, 0, 1))
       l.wid <- strwidth(varnames, "user")
-      cex.labels <- max(0.75, min(1.45, 0.85/max(l.wid)))
+      cex.labels <- max(0.75, min(1.45, 0.85 / max(l.wid)))
       text(0.5, 0.5, varnames[i], cex = cex.labels)
 
       if (type == "qq") {
@@ -547,9 +576,10 @@ matchit.covplot.subclass <- function(object, type = "qq", which.subclass = NULL,
       devAskNewPage(ask = interactive)
     }
   }
+
   devAskNewPage(ask = FALSE)
 
- invisible(NULL)
+  invisible(NULL)
 }
 
 qqplot_match <- function(x, t, w, sw, discrete.cutoff = 5, ...) {
@@ -600,7 +630,7 @@ qqplot_match <- function(x, t, w, sw, discrete.cutoff = 5, ...) {
   }
 
   if (length(u) <= discrete.cutoff) {
-    md <- min(diff(u))
+    md <- min(diff1(u))
     x0 <- jitter(x0, amount = .1 * md)
     x1 <- jitter(x1, amount = .1 * md)
   }
@@ -608,8 +638,8 @@ qqplot_match <- function(x, t, w, sw, discrete.cutoff = 5, ...) {
   rr <- range(c(x0, x1))
   plot(x0, x1, xlab = "", ylab = "", xlim = rr, ylim = rr, axes = FALSE, ...)
   abline(a = 0, b = 1)
-  abline(a = (rr[2]-rr[1])*0.1, b = 1, lty = 2)
-  abline(a = -(rr[2]-rr[1])*0.1, b = 1, lty = 2)
+  abline(a = (rr[2L] - rr[1L]) * 0.1, b = 1, lty = 2)
+  abline(a = (rr[1L] - rr[2L]) * 0.1, b = 1, lty = 2)
   axis(2)
   box()
 
@@ -651,15 +681,15 @@ qqplot_match <- function(x, t, w, sw, discrete.cutoff = 5, ...) {
   }
 
   if (length(u) <= discrete.cutoff) {
-    md <- min(diff(u))
+    md <- min(diff1(u))
     x0 <- jitter(x0, amount = .1 * md)
     x1 <- jitter(x1, amount = .1 * md)
   }
 
   plot(x0, x1, xlab = "", ylab = "", xlim = rr, ylim = rr, axes = FALSE, ...)
   abline(a = 0, b = 1)
-  abline(a = (rr[2]-rr[1])*0.1, b = 1, lty = 2)
-  abline(a = -(rr[2]-rr[1])*0.1, b = 1, lty = 2)
+  abline(a = (rr[2L] - rr[1L]) * 0.1, b = 1, lty = 2)
+  abline(a = (rr[1L] - rr[2L]) * 0.1, b = 1, lty = 2)
   box()
 }
 
@@ -670,7 +700,8 @@ ecdfplot_match <- function(x, t, w, sw, ...) {
   x.range <- x.max - x.min
 
   #Unmatched samples
-  plot(x = x, y = w, type= "n" , xlim = c(x.min - .02 * x.range, x.max + .02 * x.range),
+  plot(x = x, y = w, type = "n",
+       xlim = c(x.min - .02 * x.range, x.max + .02 * x.range),
        ylim = c(0, 1), axes = TRUE, ...)
 
   for (tr in 0:1) {
@@ -686,8 +717,10 @@ ecdfplot_match <- function(x, t, w, sw, ...) {
   box()
 
   #Matched sample
-  plot(x = x, y = w, type= "n" , xlim = c(x.min - .02 * x.range, x.max + .02 * x.range),
+  plot(x = x, y = w, type = "n",
+       xlim = c(x.min - .02 * x.range, x.max + .02 * x.range),
        ylim = c(0, 1), axes = FALSE, ...)
+
   for (tr in 0:1) {
     in.tr <- t[ord] == tr
     ordt <- ord[in.tr]
@@ -703,94 +736,27 @@ ecdfplot_match <- function(x, t, w, sw, ...) {
   box()
 }
 
-densityplot_match <- function(x, t, w, sw, ...) {
+densityplot_match <- function(x, t, w, sw, bw = NULL, cut = 3, ...) {
 
-  if (length(unique(x)) == 2L) x <- factor(x)
-
-  if (!is.factor(x)) {
-    #Density plot for continuous variable
-    small.tr <- (0:1)[which.min(c(sum(t==0), sum(t==1)))]
-    x_small <- x[t==small.tr]
-
-    x.min <- min(x)
-    x.max <- max(x)
-    #
-    A <- list(...)
-
-    bw <- A[["bw"]]
-    if (is.null(bw)) A[["bw"]] <- bw.nrd0(x_small)
-    else if (is.character(bw)) {
-      bw <- tolower(bw)
-      bw <- match_arg(bw, c("nrd0", "nrd", "ucv", "bcv", "sj", "sj-ste", "sj-dpi"))
-      A[["bw"]] <- switch(bw, nrd0 = bw.nrd0(x_small), nrd = bw.nrd(x_small),
-                          ucv = bw.ucv(x_small), bcv = bw.bcv(x_small), sj = ,
-                          `sj-ste` = bw.SJ(x_small, method = "ste"),
-                          `sj-dpi` = bw.SJ(x_small, method = "dpi"))
-    }
-    if (is.null(A[["cut"]])) A[["cut"]] <- 3
-
-    d_unmatched <- do.call("rbind", lapply(0:1, function(tr) {
-      cbind(as.data.frame(do.call("density", c(list(x[t==tr], weights = sw[t==tr],
-                                                    from = x.min - A[["cut"]]*A[["bw"]],
-                                                    to = x.max + A[["cut"]]*A[["bw"]]), A))[1:2]),
-            t = tr)
-    }))
-
-    d_matched <- do.call("rbind", lapply(0:1, function(tr) {
-      cbind(as.data.frame(do.call("density", c(list(x[t==tr], weights = w[t==tr],
-                                                    from = x.min - A[["cut"]]*A[["bw"]],
-                                                    to = x.max + A[["cut"]]*A[["bw"]]), A))[1:2]),
-            t = tr)
-    }))
-
-    y.max <- max(d_unmatched$y, d_matched$y)
-
-    #Unmatched samples
-    plot(x = d_unmatched$x, y = d_unmatched$y, type = "n",
-         xlim = c(x.min - A[["cut"]]*A[["bw"]], x.max + A[["cut"]]*A[["bw"]]),
-         ylim = c(0, 1.1*y.max), axes = TRUE, ...)
-
-    for (tr in 0:1) {
-      in.tr <- d_unmatched$t == tr
-      xt <- d_unmatched$x[in.tr]
-      yt <- d_unmatched$y[in.tr]
-
-      lines(x = xt, y = yt, type = "l", col = if (tr == 0) "grey60" else "black")
-    }
-
-    abline(h = 0)
-    box()
-
-    #Matched sample
-    plot(x = d_matched$x, y = d_matched$y, type = "n",
-         xlim = c(x.min - A[["cut"]]*A[["bw"]], x.max + A[["cut"]]*A[["bw"]]),
-         ylim = c(0, 1.1*y.max), axes = FALSE, ...)
-
-    for (tr in 0:1) {
-      in.tr <- d_matched$t == tr
-      xt <- d_matched$x[in.tr]
-      yt <- d_matched$y[in.tr]
-
-      lines(x = xt, y = yt, type = "l", col = if (tr == 0) "grey60" else "black")
-    }
-
-    abline(h = 0)
-    axis(1)
-    box()
+  if (has_n_unique(x, 2L)) {
+    x <- factor(x, nmax = 2)
   }
-  else {
+
+  u <- unique(t)
+
+  if (is.factor(x)) {
     #Bar plot for binary variable
     x_t_un <- lapply(sort(unique(t)), function(t_) {
       vapply(levels(x), function(i) {
-      wm(x[t==t_] == i, sw[t==t_])
-    }, numeric(1L))})
+        wm(x[t == t_] == i, sw[t == t_])
+      }, numeric(1L))})
 
     x_t_m <- lapply(sort(unique(t)), function(t_) {
       vapply(levels(x), function(i) {
-        wm(x[t==t_] == i, w[t==t_])
+        wm(x[t == t_] == i, w[t == t_])
       }, numeric(1L))})
 
-    ylim <- c(0, 1.1*max(unlist(x_t_un), unlist(x_t_m)))
+    ylim <- c(0, 1.1 * max(unlist(x_t_un), unlist(x_t_m)))
 
     borders <- c("grey60", "black")
     for (i in seq_along(x_t_un)) {
@@ -811,24 +777,100 @@ densityplot_match <- function(x, t, w, sw, ...) {
     abline(h = 0:1)
     box()
   }
+  else {
+    #Density plot for continuous variable
+    small.tr <- u[which.min(vapply(u, function(tr) sum(t == tr), numeric(1L)))]
+    x_small <- x[t == small.tr]
+
+    x.min <- min(x)
+    x.max <- max(x)
+
+    if (is_null(bw)) {
+      bw <- bw.nrd0(x_small)
+    }
+    else if (is.character(bw)) {
+      bw <- tolower(bw)
+      bw <- match_arg(bw, c("nrd0", "nrd", "ucv", "bcv", "sj", "sj-ste", "sj-dpi"))
+      bw <- switch(bw, nrd0 = bw.nrd0(x_small), nrd = bw.nrd(x_small),
+                   ucv = bw.ucv(x_small), bcv = bw.bcv(x_small), sj = ,
+                   `sj-ste` = bw.SJ(x_small, method = "ste"),
+                   `sj-dpi` = bw.SJ(x_small, method = "dpi"))
+    }
+
+    d_unmatched <- do.call("rbind", lapply(u, function(tr) {
+      cbind(as.data.frame(density(x[t == tr],
+                                  weights = sw[t == tr],
+                                  from = x.min - cut * bw,
+                                  to = x.max + cut * bw,
+                                  bw = bw, cut = cut, ...)[1:2]),
+            t = tr)
+    }))
+
+    d_matched <- do.call("rbind", lapply(u, function(tr) {
+      cbind(as.data.frame(density(x[t == tr],
+                                  weights = w[t == tr],
+                                  from = x.min - cut * bw,
+                                  to = x.max + cut * bw,
+                                  bw = bw, cut = cut, ...)[1:2]),
+            t = tr)
+    }))
+
+    y.max <- max(d_unmatched$y, d_matched$y)
+
+    #Unmatched samples
+    plot(x = d_unmatched$x, y = d_unmatched$y, type = "n",
+         xlim = c(x.min - cut * bw, x.max + cut * bw),
+         ylim = c(0, 1.1 * y.max),
+         axes = TRUE, ...)
+
+    for (tr in 0:1) {
+      in.tr <- d_unmatched$t == tr
+      xt <- d_unmatched$x[in.tr]
+      yt <- d_unmatched$y[in.tr]
+
+      lines(x = xt, y = yt, type = "l", col = if (tr == 0) "grey60" else "black")
+    }
+
+    abline(h = 0)
+    box()
+
+    #Matched sample
+    plot(x = d_matched$x, y = d_matched$y, type = "n",
+         xlim = c(x.min - cut * bw, x.max + cut * bw),
+         ylim = c(0, 1.1 * y.max),
+         axes = FALSE, ...)
+
+    for (tr in 0:1) {
+      in.tr <- d_matched$t == tr
+      xt <- d_matched$x[in.tr]
+      yt <- d_matched$y[in.tr]
+
+      lines(x = xt, y = yt, type = "l", col = if (tr == 0) "grey60" else "black")
+    }
+
+    abline(h = 0)
+    axis(1)
+    box()
+  }
 }
 
-hist.pscore <- function(x, xlab = "Propensity Score", freq = FALSE, ...){
+hist_pscore <- function(x, xlab = "Propensity Score", freq = FALSE, ...) {
   .pardefault <- par(no.readonly = TRUE)
   on.exit(par(.pardefault))
 
   treat <- x$treat
   pscore <- x$distance[!is.na(x$distance)]
-  s.weights <- if (is.null(x$s.weights)) rep(1, length(treat)) else x$s.weights
+
+  s.weights <- {
+    if (is_null(x$s.weights)) rep.int(1, length(treat))
+    else x$s.weights
+  }
+
   weights <- x$weights * s.weights
-  matched <- weights != 0
   q.cut <- x$q.cut
 
   minp <- min(pscore)
   maxp <- max(pscore)
-  ratio <- x$call$ratio
-
-  if (is.null(ratio)) ratio <- 1
 
   if (freq) {
     weights <- .make_sum_to_n(weights, by = treat)
@@ -841,69 +883,73 @@ hist.pscore <- function(x, xlab = "Propensity Score", freq = FALSE, ...){
 
   ylab <- if (freq) "Count" else "Proportion"
 
-  par(mfrow = c(2,2))
+  par(mfrow = c(2, 2))
   # breaks <- pretty(na.omit(pscore), 10)
   breaks <- seq(minp, maxp, length = 11)
   xlim <- range(breaks)
 
   for (n in c("Raw Treated", "Matched Treated", "Raw Control", "Matched Control")) {
-    if (startsWith(n, "Raw")) w <- s.weights
-    else w <- weights
+    w <- if (startsWith(n, "Raw")) s.weights else weights
 
-    if (endsWith(n, "Treated")) t <- 1
-    else t <- 0
+    tr <- if (endsWith(n, "Treated")) 1 else 0
 
     #Create histogram using weights
     #Manually assign density, which is used as height of the bars. The scaling
     #of the weights above determine whether they are "counts" or "proportions".
     #Regardless, set freq = FALSE in plot() to ensure density is used for bar
     #height rather than count.
-    pm <- hist(pscore[treat==t], plot = FALSE, breaks = breaks)
-    pm[["density"]] <- vapply(seq_len(length(pm$breaks) - 1), function(i) {
-      sum(w[treat == t & pscore >= pm$breaks[i] & pscore < pm$breaks[i+1]])
+    pm <- hist(pscore[treat == tr], plot = FALSE, breaks = breaks)
+    pm[["density"]] <- vapply(seq_len(length(pm$breaks) - 1L), function(i) {
+      sum(w[treat == tr & pscore >= pm$breaks[i] & pscore < pm$breaks[i + 1L]])
     }, numeric(1L))
+
     plot(pm, xlim = xlim, xlab = xlab, main = n, ylab = ylab,
          freq = FALSE, col = "lightgray", ...)
 
-    if (!startsWith(n, "Raw") && !is.null(q.cut)) abline(v = q.cut, lty=2)
+    if (!startsWith(n, "Raw") && is_not_null(q.cut)) {
+      abline(v = q.cut, lty = 2)
+    }
   }
 
 }
 
-jitter.pscore <- function(x, interactive, pch = 1, ...){
+jitter_pscore <- function(x, interactive, pch = 1, ...) {
 
   .pardefault <- par(no.readonly = TRUE)
   on.exit(par(.pardefault))
 
   treat <- x$treat
   pscore <- x$distance
-  s.weights <- if (is.null(x$s.weights)) rep(1, length(treat)) else x$s.weights
+  s.weights <- if (is_null(x$s.weights)) rep.int(1, length(treat)) else x$s.weights
   weights <- x$weights * s.weights
   matched <- weights > 0
   q.cut <- x$q.cut
-  jitp <- jitter(rep(1,length(treat)), factor=6)+(treat==1)*(weights==0)-(treat==0) - (weights==0)*(treat==0)
+  jitp <- jitter(rep.int(1, length(treat)), factor = 6) + (treat == 1) * (weights == 0) - (treat == 0) - (weights==0) * (treat == 0)
   cswt <- sqrt(s.weights)
   cwt <- sqrt(weights)
   minp <- min(pscore, na.rm = TRUE)
   maxp <- max(pscore, na.rm = TRUE)
 
-  plot(pscore, xlim = c(minp - 0.05*(maxp-minp), maxp + 0.05*(maxp-minp)), ylim = c(-1.5,2.5),
+  plot(pscore, xlim = c(minp - 0.05 * (maxp-minp), maxp + 0.05 * (maxp - minp)), ylim = c(-1.5, 2.5),
        type = "n", ylab = "", xlab = "Propensity Score",
        axes = FALSE, main = "Distribution of Propensity Scores", ...)
-  if (!is.null(q.cut)) abline(v = q.cut, col = "grey", lty = 1)
+
+  if (is_not_null(q.cut)) {
+    abline(v = q.cut, col = "grey", lty = 1)
+  }
 
   #Matched treated
-  points(pscore[treat==1 & matched], jitp[treat==1 & matched],
-         pch = pch, cex = cwt[treat==1 & matched], ...)
+  points(pscore[treat == 1 & matched], jitp[treat == 1 & matched],
+         pch = pch, cex = cwt[treat == 1 & matched], ...)
   #Matched control
-  points(pscore[treat==0 & matched], jitp[treat==0 & matched],
-         pch = pch, cex = cwt[treat==0 & matched], ...)
+  points(pscore[treat == 0 & matched], jitp[treat == 0 & matched],
+         pch = pch, cex = cwt[treat == 0 & matched], ...)
   #Unmatched treated
-  points(pscore[treat==1 & !matched], jitp[treat==1 & !matched],
-         pch = pch, cex = cswt[treat==1 & matched],...)
+  points(pscore[treat == 1 & !matched], jitp[treat == 1 & !matched],
+         pch = pch, cex = cswt[treat == 1 & !matched], ...)
   #Unmatched control
-  points(pscore[treat==0 & !matched], jitp[treat==0 & !matched],
-         pch = pch, cex = cswt[treat==0 & matched], ...)
+  points(pscore[treat == 0 & !matched], jitp[treat == 0 & !matched],
+         pch = pch, cex = cswt[treat == 0 & !matched], ...)
 
   axis(1)
 
