@@ -62,16 +62,19 @@
 #'
 #' data("lalonde")
 #' m.out <- matchit(treat ~ age + educ + married +
-#'                    race + re74, data = lalonde,
+#'                    race + re74,
+#'                  data = lalonde,
 #'                  method = "nearest")
 #' plot(summary(m.out, interactions = TRUE),
 #'      var.order = "unmatched")
 #'
 #' s.out <- matchit(treat ~ age + educ + married +
 #'                    race + nodegree + re74 + re75,
-#'                  data = lalonde, method = "subclass")
+#'                  data = lalonde,
+#'                  method = "subclass")
 #' plot(summary(s.out, subclass = TRUE),
-#'      var.order = "unmatched", abs = FALSE)
+#'      var.order = "unmatched",
+#'      abs = FALSE)
 #'
 #' @exportS3Method plot summary.matchit
 plot.summary.matchit <- function(x,
@@ -85,20 +88,25 @@ plot.summary.matchit <- function(x,
   on.exit(par(.pardefault))
 
   sub <- inherits(x, "summary.matchit.subclass")
-  matched <- sub || !is.null(x[["sum.matched"]])
-  un <- !is.null(x[["sum.all"]])
+  matched <- sub || is_not_null(x[["sum.matched"]])
+  un <- is_not_null(x[["sum.all"]])
 
-  standard.sum <- if (un) x[["sum.all"]] else x[[if (sub) "sum.across" else "sum.matched"]]
+  standard.sum <- {
+    if (un) x[["sum.all"]]
+    else if (sub) x[["sum.across"]]
+    else x[["sum.matched"]]
+  }
 
   if (!"Std. Mean Diff." %in% colnames(standard.sum)) {
     .err("not appropriate for unstandardized summary. Run `summary()` with the `standardize = TRUE` option, and then plot")
   }
 
   if (un) {
-    sd.all <- x[["sum.all"]][,"Std. Mean Diff."]
+    sd.all <- x[["sum.all"]][, "Std. Mean Diff."]
   }
+
   if (matched) {
-    sd.matched <- x[[if (sub) "sum.across" else "sum.matched"]][,"Std. Mean Diff."]
+    sd.matched <- x[[if (sub) "sum.across" else "sum.matched"]][, "Std. Mean Diff."]
   }
 
   chk::chk_flag(abs)
@@ -108,8 +116,13 @@ plot.summary.matchit <- function(x,
   chk::chk_string(var.order)
   var.order <- match_arg(var.order, c("data", "matched", "unmatched", "alphabetical"))
 
-  if (!un && var.order == "unmatched") .err("`var.order` cannot be \"unmatched\" if `un = TRUE` in the call to `summary()`")
-  if (!matched && var.order == "matched") .err("`var.order` cannot be \"matched\" if `method = NULL` in the original call to `matchit()`")
+  if (!un && var.order == "unmatched") {
+    .err('`var.order` cannot be "unmatched" if `un = TRUE` in the call to `summary()`')
+  }
+
+  if (!matched && var.order == "matched") {
+    .err('`var.order` cannot be "matched" if `method = NULL` in the original call to `matchit()`')
+  }
 
   if (abs) {
     if (un) sd.all <- abs(sd.all)
@@ -131,9 +144,9 @@ plot.summary.matchit <- function(x,
            bg = NA, color = NA, ...)
   abline(v = 0)
 
-  if (sub && length(x$sum.subclass) > 0) {
+  if (sub && is_not_null(x$sum.subclass)) {
     for (i in seq_along(x$sum.subclass)) {
-      sd.sub <- x$sum.subclass[[i]][,"Std. Mean Diff."]
+      sd.sub <- x$sum.subclass[[i]][, "Std. Mean Diff."]
       if (abs) sd.sub <- abs(sd.sub)
       points(x = sd.sub[ord], y = seq_along(sd.sub),
              pch = as.character(i), col = "gray60", cex = .6)
@@ -144,12 +157,13 @@ plot.summary.matchit <- function(x,
     points(x = sd.all[ord], y = seq_along(sd.all),
            pch = 21, bg = "white", col = "black")
   }
+
   if (matched) {
     points(x = sd.matched[ord], y = seq_along(sd.matched),
            pch = 21, bg = "black", col = "black")
   }
 
-  if (!is.null(threshold)) {
+  if (is_not_null(threshold)) {
     if (abs) {
       abline(v = threshold, lty = seq_along(threshold))
     }
@@ -159,12 +173,13 @@ plot.summary.matchit <- function(x,
     }
   }
 
-  if (sum(matched, un) > 1 && !is.null(position)) {
+  if (sum(matched, un) > 1 && is_not_null(position)) {
     position <- match_arg(position, c("bottomright", "bottom", "bottomleft", "left",
                                       "topleft", "top", "topright", "right", "center"))
     legend(position, legend = c("All", "Matched"),
            pt.bg = c("white", "black"), pch = 21,
            inset = .015, xpd = TRUE)
   }
+
   invisible(x)
 }
